LoadProgress

Enum LoadProgress 

pub enum LoadProgress {
    HyperparametersLoaded,
    ContextSize {
        bytes: usize,
    },
    TensorLoaded {
        current_tensor: usize,
        tensor_count: usize,
    },
    Loaded {
        file_size: u64,
        tensor_count: usize,
    },
}
Each variant represents a step within the process of loading the model. These can be used to report progress to the user.

Variants



HyperparametersLoaded

The hyperparameters have been loaded from the model.



ContextSize

The context has been created.

Fields

bytes: usize

The size of the context.



TensorLoaded

A tensor from the current part has been loaded.

Fields

current_tensor: usize

The current tensor (0-indexed).

tensor_count: usize

The number of total tensors.



Loaded

A model part has finished fully loading.

Fields

file_size: u64

The number of bytes in the part.

tensor_count: usize

The number of tensors in the part.